//+------------------------------------------------------------------+
//|                                                Andre EA v1.1.mq4 |
//|                                       Copyright  2008 Tom Balfe |
//|                   http://www.forex-tsd.com/members/nittany1.html |
//|                                                                  |
//| Moving Average based Expert Advisor. I added stochastics and     |
//| directional index to try to help filter out bad trades.          |
//+------------------------------------------------------------------+

#property copyright "Copyright  2008 Tom Balfe"
#property link      "http://www.forex-tsd.com/members/nittany1.html"

//+------------------------------------------------------------------+
//| USER ADJUSTABLE STUFF                                            |
//+------------------------------------------------------------------+

extern  string  TopOfSetting          = "=== Andre v1.1 EA ===";
extern  int     MagicNumber           = 112722;

extern  string  Order_Settings        = "=== Order Settings ===";
extern  double  StaticLots            = 0.1;
extern  int     Slippage              = 5;
extern  int     TP                    = 120;
extern  int     SL                    = 60;

extern  string  MM_Settings           = "=== Money Management ===";
extern  bool    UseMM                 = false;
extern  int     PercentAtRisk         = 3;

//+------------------------------------------------------------------+
//| DON'T CHANGE BELOW HERE                                          |
//+------------------------------------------------------------------+
//| Program initializes and deinitializes here. Must delete the      |
//| objects we placed in case user takes expert off that chart.      |
//+------------------------------------------------------------------+
string        EAComment   = "Andre v1.1 EA";
int           OpenOrders  = 1;
datetime      PreviousBar;

int init()
  {

  return(0);
  }

int deinit()
  {
    if (TotalOpenOrders() > 0)
    {
    CloseAll();
    } 
   
  return(0);
  }

int start()
  {
  //--- Moving Average
  double shortMA      = iMA(NULL,0,5,0,MODE_EMA,PRICE_CLOSE,0);
  double longMA       = iMA(NULL,0,9,0,MODE_LWMA,PRICE_CLOSE,0);
  
  //--- Stochastics
  double sMain        = iStochastic(NULL,0,8,3,3,MODE_SMA,0,MODE_MAIN,0);
  double sSignal      = iStochastic(NULL,0,8,3,3,MODE_SMA,0,MODE_SIGNAL,0);
  
  //--- Directional Index
  double di_p         = iADX(NULL,0,14,PRICE_CLOSE,1,0); // DI+ 
  double di_m         = iADX(NULL,0,14,PRICE_CLOSE,2,0); // DI-   
  
  //------------------- order management -------------------//
  if (NewBar() == true) {
  
    //---------------- check indicators and look for a CLOSE ---//
    if (TotalOpenOrders() == OpenOrders)
    {
      if (OrderType() == OP_BUY) {
        if ((sSignal > sMain)||(longMA > shortMA)){ CloseAll(); }
      }
      if (OrderType() == OP_SELL) {
        if ((sMain > sSignal)&&(shortMA > longMA)){ CloseAll(); }
      }
    }
    //---------------- check indicators and look for a ORDER ENTRY ---//
    if (TotalOpenOrders() < OpenOrders)
    {
      if ((sMain > sSignal)&&(shortMA > longMA)&&(di_p > di_m)) // BUY
        {
        OrderSend(Symbol(),OP_BUY,LotSize(),Ask,Slippage,Ask-SL*Point,Ask+TP*Point,EAComment,MagicNumber,0,Lime);  
        }  
      if ((sSignal > sMain)&&(longMA > shortMA)&&(di_m > di_p)) // SELL
        {
        OrderSend(Symbol(),OP_SELL,LotSize(),Bid,Slippage,Bid+SL*Point,Ask-TP*Point,EAComment,MagicNumber,0,Red);
        }
    }
  }
  
  return(0);
  }

//+------------------------------------------------------------------+
//| COMMON FUNCTIONS                                                 |
//+------------------------------------------------------------------+
//| The expert will call these from the main loop.                   |
//+------------------------------------------------------------------+

//+-----------------------------------------------------+
//|           new bar                                   |
//+-----------------------------------------------------+
bool NewBar()
{
  if(PreviousBar<Time[0])
  {
    PreviousBar = Time[0];
    return(true);
  }
  else
  {
    return(false);
  }
  return(false);  
}

//+-----------------------------------------------------+
//|           calculate lot size                        |
//+-----------------------------------------------------+
double LotSize()
{
  if (UseMM == true) 
    { double Lots = MathCeil(AccountFreeMargin() *  PercentAtRisk / 1000) / 100; }
  
  else { Lots = StaticLots; }
  
  return(Lots);  
}

//+-----------------------------------------------------+
//|           close all                                 |
//+-----------------------------------------------------+
//| Finds any open orders & closes them                 |
//+-----------------------------------------------------+
void CloseAll()
{
  int total = OrdersTotal();
  for(int i=total-1;i>=0;i--)
  {
    OrderSelect(i, SELECT_BY_POS);
    int type = OrderType();
    
    if (OrderSymbol()==Symbol() && (OrderMagicNumber() == MagicNumber))  
    {
      //-- Close open BUYs
      if (type == OP_BUY) OrderClose(OrderTicket(),OrderLots(),MarketInfo(OrderSymbol(),MODE_BID),Slippage,CornflowerBlue);
      //-- Close open SELLS
      if (type == OP_SELL) OrderClose(OrderTicket(),OrderLots(),MarketInfo(OrderSymbol(),MODE_ASK),Slippage,CornflowerBlue);
    }
  }
  return;
}

//+-----------------------------------------------------+
//|           calculate open orders                     |
//+-----------------------------------------------------+
int TotalOpenOrders()
{
  int j = 0;
  j=OrdersTotal();
  int TotalOpenOrders = 0;
   
  if(j==0) { return (0); }
  
  else
  {
    for(;j>=0;j--)
      {
      RefreshRates();
      OrderSelect(j,SELECT_BY_POS);
      if(OrderMagicNumber()==MagicNumber)
      {
        TotalOpenOrders++;
      }
    }
  }
  return(TotalOpenOrders);
}

